Stub for a conversation holding an ordered list of messages. (Phase 4)
Summary
Types
@type t() :: %PhoenixAI.Conversation{ id: String.t() | nil, messages: [PhoenixAI.Message.t()], metadata: map() }
Stub for a conversation holding an ordered list of messages. (Phase 4)
@type t() :: %PhoenixAI.Conversation{ id: String.t() | nil, messages: [PhoenixAI.Message.t()], metadata: map() }